
function [Fac,timeSpent,his] = MYRON(X,K, ops)

    if ~isfield(ops, 'la'), ops.la = .2; end %reg param on sparseness
    if ~isfield(ops,'version'),ops.version = 3; end
    if ~isfield(ops,'scaleP'),ops.scaleP = 1; end
    if ~isfield(ops, 'gnoisev1'),ops.gnoisev1 = 0; end
    if ~isfield(ops, 'gnoisev3'),ops.gnoisev3 = 0; end
    if ~isfield(ops, 'maxitr' ),    ops.maxitr = 200; end
    if ~isfield(ops, 'maxtime'),    ops.maxtime = 6000; end
    if ~isfield(ops, 'tol'),        ops.tol = 1e-6; end
    if ~isfield(ops, 'global'), ops.global='fullA'; end
    if ~isfield(ops, 'globalC'),ops.globalC = 'weighted'; end
    if ~isfield(ops,'shape'), ops.shape='bursty'; end
    
    
    sz=size(X);
    N1 = sz(1);
    N2 = sz(2);
    T = sz(3);
   
    if isfield(ops,'dense') && ops.dense, X = tensor(X); end
    if ~isfield(ops,'Binit')
        ops.Binit{1} = ones(N1,1);
        ops.Binit{2} = ones(N2,1);
        ops.Binit{3} = ones(T,1)*collapse(X)/prod(size(X));
    end
    if strcmp(ops.globalC,'weighted')
        ops.Binit{1} = arrayfun(@(i) sumFiber(X,i,1), (1:N1)');
        ops.Binit{1} = ops.Binit{1}/sum(ops.Binit{1})*N1;
        ops.Binit{2} = arrayfun(@(i) sumFiber(X,i,2),(1:N2)');
        ops.Binit{2} = ops.Binit{2}/sum(ops.Binit{2})*N2;
    end
    ops.opsB.constraint = {'shape','shape','nonnegative'};
    ops.opsB.mu = 0;
    if ~isfield(ops.opsB,'la'),ops.opsB.la = 1e6; end
    ops.opsB.B = ops.Binit;
%     if isfield(ops,'gnoisev2') && ops.gnoisev2, X = X-collapse(X)/prod(size(X)); end    
    if ~isfield(ops,'Hinit') 
        Hinit{1} = rand( N1, K );
        Hinit{2} = rand( N2, K );
        Hinit{3} = rand( T, K );
        for d = 1:3
            Hinit{d} = Hinit{d} / diag( sqrt( sum( Hinit{d}.^2 ) ) );
        end
        ops.Hinit = Hinit;
    end
    if ~isfield(ops,'constraint')
        ops.constraint{1} = 'nonnegative';
        if strcmp(ops.shape,'none'), ops.constraint{3} = 'nonnegative'; %THIS IS NOT THE ORIGINAL TF
        else, ops.constraint{3} = 'shape'; end
        ops.constraint{2} = 'nonnegative';
    end
    
    if strcmp(ops.shape,'bursty')
        if ~isfield(ops,'params')
            params.ab = 0.5*ones(K,1);
            params.a0 = params.ab;
            params.b = params.ab;
            params.g = params.ab;
            ops.params = params;
        end
    elseif strcmp(ops.shape,'wavelet')
        if ~isfield(ops,'wavelet'),ops.wavelet='db4'; end
        if ~isfield(ops,'N'),ops.N = ceil(log2(T)); end
        if ~isfield(ops,'thresh'),ops.thresh=0.02; end
        if strcmp(ops.wavelet,'mat') && ~isfield(ops,'l'), ops.l=1;end
    end
    %% BRC
    doFit = tic;
    [ Fac, scale, params, approx, ground, his] = MYRON_Algo(X, K, ops);
    timeSpent = toc(doFit); 
    Fac{4} = scale;
    Fac{5} = params;
    Fac{6} = ground;
    Fac{7} = approx;
   
end

function n = sumFiber(X,i,d)
    if d == 1
        [~,v]=find(X(i,:,:));
    elseif d==2
        [~,v]=find(X(:,i,:));
    end
    n = sum(v);
end
